@@ -73,6 +73,9 @@
 #define  XC_HYB_GGA_XC_PBE_MOLB0        276  /* PBEmolbeta0                                                          */
 #define  XC_HYB_GGA_XC_PBE50            290  /* PBE0 with 50% exx                                                    */
 #define  XC_HYB_GGA_XC_HFLYP            314  /*Hartree-Fock + LYP correlation                                        */
+#define  XC_HYB_GGA_XC_PBE_2X           392  /* PBE0 with 56% exx                                                    */
+#define  XC_HYB_GGA_XC_PBE38            393  /* PBE0 with 3/8 = 37.5% exx                                            */
+#define  XC_HYB_GGA_XC_B3LYP3           394  /* B3LYP with VWN functional 3 instead of RPA                           */
 #define  XC_HYB_GGA_XC_CAM_O3LYP        395  /*range separated hybrid based on the optx functional                   */
 #define  XC_HYB_GGA_XC_WB97X_D3         399  /* Lin et al                                                            */
 #define  XC_HYB_GGA_XC_LC_BLYP          400  /*Long-range corrected BLYP                                             */
@@ -153,6 +156,7 @@
 #define  XC_HYB_GGA_X_S12H              496  /*Swart 2012 GGA hybrid exchange                                        */
 #define  XC_HYB_GGA_XC_BLYP35           499  /* Becke 1-parameter mixture for mixed-valence systems                  */
 #define  XC_HYB_GGA_XC_B5050LYP         572  /* Like B3LYP but more exact exchange                                   */
+#define  XC_HYB_GGA_XC_LB07             589  /*Livshits and Baer, empirical functional also used for IP tuning       */
 #define  XC_HYB_GGA_XC_APBE0            607  /*Hybrid based on APBE                                                  */
 #define  XC_HYB_GGA_XC_HAPBE            608  /* Hybrid based in APBE and zvPBEloc                                    */
 #define  XC_HYB_GGA_XC_RCAM_B3LYP       610  /* Similar to CAM-B3LYP, but trying to reduce the many-electron self-interaction*/
@@ -164,6 +168,7 @@
 #define  XC_HYB_GGA_XC_LC_BOP           636  /* Long-range corrected B88 with B88OP correlation                      */
 #define  XC_HYB_GGA_XC_LC_PBEOP         637  /* Long-range corrected PBE with PBEOP correlation                      */
 #define  XC_HYB_GGA_XC_LC_BLYPR         639  /* Long-range corrected BLYP with correlation only in short-range       */
+#define  XC_HYB_GGA_XC_MCAM_B3LYP       640  /* Modified CAM-B3LYP                                                   */
 #define  XC_HYB_GGA_XC_CAM_PBEH         681  /* CAM version of PBEH                                                  */
 #define  XC_HYB_GGA_XC_CAMY_PBEH        682  /* PBEH with Yukawa screening                                           */
 #define  XC_GGA_X_GAM                    32  /* GAM functional from Minnesota                                        */
@@ -394,7 +399,6 @@
 #define  XC_GGA_C_CS1                   565  /*A dynamical correlation functional                                    */
 #define  XC_GGA_X_B88M                  570  /* Becke 88 reoptimized to be used with mgga_c_tau1                     */
 #define  XC_GGA_XC_KT3                  587  /* Keal and Tozer version 3                                             */
-#define  XC_GGA_XC_LB07                 589  /* Livshits and Baer, empirical functional                              */
 #define  XC_GGA_K_GDS08                 591  /*Combined analytical theory with Monte Carlo sampling                  */
 #define  XC_GGA_K_GHDS10                592  /* As GDS08 but for an electron gas with spin                           */
 #define  XC_GGA_K_GHDS10R               593  /* Reparametrized GHDS10                                                */
@@ -592,3 +596,4 @@
 #define  XC_MGGA_X_MBR                  716  /*modified Becke-Roussel by Patra et al                                 */
 #define  XC_MGGA_X_R2SCANL              718  /*Deorbitalized r^2SCAN exchange                                        */
 #define  XC_MGGA_C_R2SCANL              719  /*Deorbitalized r^2SCAN correlation                                     */
+#define  XC_MGGA_X_MTASK                724  /* modified TASK exchange                                               */
